@@ -1,15 +1,14 @@
 ;;; organize-imports-java.el --- Automatically organize imports in Java code  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2018-2021  Shen, Jen-Chieh
+;; Copyright (C) 2018-2026  Shen, Jen-Chieh
 ;; Created date 2018-04-16 13:12:01
 
 ;; Author: Shen, Jen-Chieh <jcs090218@gmail.com>
-;; Description: Automatically organize imports in Java code.
-;; Keyword: organize imports java handy eclipse
-;; Package-Version: 0.3.0
-;; Package-Revision: 6e0b1d094bc6
-;; Package-Requires: ((emacs "25.1") (f "0.20.0") (s "1.12.0") (dash "2.14.1") (ht "2.2"))
 ;; URL: https://github.com/jcs-elpa/organize-imports-java
+;; Package-Version: 20260101.601
+;; Package-Revision: 0782a1814104
+;; Package-Requires: ((emacs "25.1") (f "0.20.0") (s "1.12.0") (dash "2.14.1") (ht "2.2"))
+;; Keywords: convenience organize imports java eclipse
 
 ;; This file is NOT part of GNU Emacs.
 
@@ -141,7 +140,8 @@
   "Priority list of the insertion.  Insertion will be base on this list order.")
 
 (defvar organize-imports-java--same-class-name-list '()
-  "Paths will store temporary, use to check if multiple class exists in the environment.")
+  "Paths will store temporary, use to check if multiple class exists in the
+environment.")
 
 (defvar organize-imports-java--default-oij-config
   (expand-file-name "default/oij.config" organize-imports-java--home-dir)
@@ -343,10 +343,11 @@ IN-KEY : key to search for value."
   (let* ((src-file-path-list '())
          (project-source-dir (concat (organize-imports-java--project-dir)
                                      organize-imports-java-source-dir-name "/")))
-    (setq src-file-path-list (f--files project-source-dir
-                                       (and (string= (f-ext it) "java")
-                                            (not (string-match-p "#" (f-filename it))))
-                                       t))
+    (when (file-directory-p project-source-dir)
+      (setq src-file-path-list (f--files project-source-dir
+                                         (and (string= (f-ext it) "java")
+                                              (not (string-match-p "#" (f-filename it))))
+                                         t)))
 
     (let ((index 0) (current-dirname "") (last-dirname ""))
       (dolist (src-file-path src-file-path-list)
